keras_bed_sequence
=========================================================================================
|travis| |sonar_quality| |sonar_maintainability| |codacy|
|code_climate_maintainability| |pip| |downloads|

Lazily one-hot encoding bed sequences using Keras Sequence.

How do I install this package?
----------------------------------------------
As usual, just download it using pip:

.. code:: shell

    pip install keras_bed_sequence

Tests Coverage
----------------------------------------------
Since some software handling coverages sometimes get
slightly different results, here's three of them:

|coveralls| |sonar_coverage| |code_climate_coverage|



.. |travis| image:: https://travis-ci.org/LucaCappelletti94/keras_bed_sequence.png
   :target: https://travis-ci.org/LucaCappelletti94/keras_bed_sequence
   :alt: Travis CI build

.. |sonar_quality| image:: https://sonarcloud.io/api/project_badges/measure?project=LucaCappelletti94_keras_bed_sequence&metric=alert_status
    :target: https://sonarcloud.io/dashboard/index/LucaCappelletti94_keras_bed_sequence
    :alt: SonarCloud Quality

.. |sonar_maintainability| image:: https://sonarcloud.io/api/project_badges/measure?project=LucaCappelletti94_keras_bed_sequence&metric=sqale_rating
    :target: https://sonarcloud.io/dashboard/index/LucaCappelletti94_keras_bed_sequence
    :alt: SonarCloud Maintainability

.. |sonar_coverage| image:: https://sonarcloud.io/api/project_badges/measure?project=LucaCappelletti94_keras_bed_sequence&metric=coverage
    :target: https://sonarcloud.io/dashboard/index/LucaCappelletti94_keras_bed_sequence
    :alt: SonarCloud Coverage

.. |coveralls| image:: https://coveralls.io/repos/github/LucaCappelletti94/keras_bed_sequence/badge.svg?branch=master
    :target: https://coveralls.io/github/LucaCappelletti94/keras_bed_sequence?branch=master
    :alt: Coveralls Coverage

.. |pip| image:: https://badge.fury.io/py/keras-bed-sequence.svg
    :target: https://badge.fury.io/py/keras-bed-sequence
    :alt: Pypi project

.. |downloads| image:: https://pepy.tech/badge/keras-bed-sequence
    :target: https://pepy.tech/badge/keras-bed-sequence
    :alt: Pypi total project downloads

.. |codacy| image:: https://api.codacy.com/project/badge/Grade/6bb591f3d405443a9549967eac35b723
    :target: https://www.codacy.com/manual/LucaCappelletti94/keras_bed_sequence?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=LucaCappelletti94/keras_bed_sequence&amp;utm_campaign=Badge_Grade
    :alt: Codacy Maintainability

.. |code_climate_maintainability| image:: https://api.codeclimate.com/v1/badges/d601fb2c7485f1ac3433/maintainability
    :target: https://codeclimate.com/github/LucaCappelletti94/keras_bed_sequence/maintainability
    :alt: Maintainability

.. |code_climate_coverage| image:: https://api.codeclimate.com/v1/badges/d601fb2c7485f1ac3433/test_coverage
    :target: https://codeclimate.com/github/LucaCappelletti94/keras_bed_sequence/test_coverage
    :alt: Code Climate
